﻿using System;
using System.Drawing;

using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraTreeList;
using DevExpress.XtraTreeList.Nodes;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load                                 += Form_Load;
            this.treeList.CustomScrollAnnotation += treeList_CustomScrollAnnotation;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.treeList.RowHeight                                      = 25;
            this.treeList.OptionsView.AutoWidth                          = false;
            this.treeList.OptionsBehavior.ReadOnly                       = true;
            this.treeList.OptionsBehavior.PopulateServiceColumns         = true;
            this.treeList.OptionsScrollAnnotations.ShowCustomAnnotations = DefaultBoolean.True;
            this.treeList.KeyFieldName                                   = "ID";
            this.treeList.ParentFieldName                                = "RegionID";

            this.treeList.DataSource = SalesData.GetSalesDataList();

            this.treeList.Columns[this.treeList.KeyFieldName   ].Visible = false;
            this.treeList.Columns[this.treeList.ParentFieldName].Visible = false;

            this.treeList.BestFitColumns();

            this.treeList.ExpandAll();
        }

        #endregion
        #region 트리 리스트 스크롤 주석 커스텀 설정하기 - treeList_CustomScrollAnnotation(sender, e)

        /// <summary>
        /// 트리 리스트 스크롤 주석 커스텀 설정하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void treeList_CustomScrollAnnotation(object sender, TreeListCustomScrollAnnotationsEventArgs e)
        {
            TreeList treeList = sender as TreeList;

            TreeListNode node = treeList.FindNodeByFieldValue("Region", "Spain");

            e.SetAnnotations(Color.Orange, node);
        }

        #endregion
    }
}